@@ -2,6 +2,7 @@ from urllib.parse import urljoin
 
 from .add_ons.clients import AddOnClient
 from .billable_metrics.clients import BillableMetricClient
+from .billing_entities.clients import BillingEntityClient
 from .coupons.clients import AppliedCouponClient, CouponClient
 from .credit_notes.clients import CreditNoteClient
 from .customers.clients import CustomerClient
@@ -14,6 +15,7 @@ from .invoiced_usages.clients import InvoicedUsageClient
 from .mrrs.clients import MrrClient
 from .organizations.clients import OrganizationClient
 from .overdue_balances.clients import OverdueBalanceClient
+from .payment_receipts.clients import PaymentReceiptClient
 from .payment_requests.clients import PaymentRequestClient
 from .payments.clients import PaymentClient
 from .invoice_collections.clients import InvoiceCollectionClient
@@ -67,6 +69,10 @@ class Client:
     def billable_metrics(self) -> BillableMetricClient:
         return BillableMetricClient(self.base_api_url, self.api_key)
 
+    @callable_cached_property
+    def billing_entities(self) -> BillingEntityClient:
+        return BillingEntityClient(self.base_api_url, self.api_key)
+
     @callable_cached_property
     def coupons(self) -> CouponClient:
         return CouponClient(self.base_api_url, self.api_key)
@@ -115,6 +121,10 @@ class Client:
     def overdue_balances(self) -> OverdueBalanceClient:
         return OverdueBalanceClient(self.base_api_url, self.api_key)
 
+    @callable_cached_property
+    def payment_receipts(self) -> PaymentReceiptClient:
+        return PaymentReceiptClient(self.base_api_url, self.api_key)
+
     @callable_cached_property
     def payment_requests(self) -> PaymentRequestClient:
         return PaymentRequestClient(self.base_api_url, self.api_key)
