@@ -7,6 +7,12 @@ from .billable_metric import (
     BillableMetricEvaluateExpression as BillableMetricEvaluateExpression,
     BillableMetricEvaluateExpressionResponse as BillableMetricEvaluateExpressionResponse,
 )
+from .billing_entity import (
+    BillingEntity as BillingEntity,
+    BillingEntityUpdate as BillingEntityUpdate,
+    BillingEntityResponse as BillingEntityResponse,
+    BillingEntityBillingConfiguration as BillingEntityBillingConfiguration,
+)
 from .billing_period import (
     BillingPeriodResponse as BillingPeriodResponse,
     BillingPeriodsResponse as BillingPeriodsResponse,
@@ -90,6 +96,10 @@ from .usage_threshold import (
     UsageThresholds as UsageThresholds,
     UsageThresholdsResponse as UsageThresholdsResponse,
 )
+from .payment_receipt import (
+    PaymentReceiptResponse as PaymentReceiptResponse,
+    PaymentReceiptsResponse as PaymentReceiptsResponse,
+)
 from .payment_request import PaymentRequest as PaymentRequest
 from .payment import Payment as Payment
 from .lifetime_usage import LifetimeUsageResponse as LifetimeUsageResponse
